# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-05-15 06:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('async_notifications', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='emailnotification',
            options={'verbose_name': 'Email notification', 'verbose_name_plural': 'Email notifications'},
        ),
        migrations.AlterModelOptions(
            name='emailtemplate',
            options={'verbose_name': 'Email template', 'verbose_name_plural': 'Email templates'},
        ),
        migrations.AlterField(
            model_name='emailtemplate',
            name='code',
            field=models.CharField(max_length=50, verbose_name='Code'),
        ),
    ]
