# Generated by Django 3.0.3 on 2020-02-28 22:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('async_notifications', '0003_templatecontext'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailnotification',
            name='bcc',
            field=models.TextField(blank=True, null=True, verbose_name='Bcc Blind carbon copy list'),
        ),
        migrations.AddField(
            model_name='emailnotification',
            name='cc',
            field=models.TextField(blank=True, null=True, verbose_name='Cc Carbon Copy list'),
        ),
        migrations.AddField(
            model_name='emailtemplate',
            name='bcc',
            field=models.TextField(blank=True, null=True, verbose_name='Bcc Blind carbon copy list'),
        ),
        migrations.AddField(
            model_name='emailtemplate',
            name='cc',
            field=models.TextField(blank=True, null=True, verbose_name='Cc Carbon Copy list'),
        ),
    ]
