# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-21 05:41
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailNotification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=500, verbose_name='Subject')),
                ('message', models.TextField(verbose_name='Message')),
                ('recipient', models.TextField(verbose_name='Recipient list')),
                ('enqueued', models.BooleanField(default=True, verbose_name='Enqueued')),
                ('sended', models.BooleanField(default=False, verbose_name='Sended')),
                ('file', models.FileField(blank=True, null=True, upload_to='email/%Y/%M', verbose_name='File')),
                ('problems', models.BooleanField(default=False, verbose_name='Problems')),
                ('create_datetime', models.DateTimeField(auto_now_add=True, verbose_name='Create datetime')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
        ),
        migrations.CreateModel(
            name='EmailTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.CharField(max_length=20, verbose_name='Code')),
                ('subject', models.CharField(max_length=500, verbose_name='Subject')),
                ('message', models.TextField(verbose_name='Message')),
            ],
        ),
    ]
